@@ -1,7 +1,7 @@
 import torch
 import gpytorch
 import numpy as np
-import os 
+import os
 from math import pi
 
 def optimise_model (model, X_train, y_train_std, likelihood, mll):
@@ -24,7 +24,7 @@ def optimise_model (model, X_train, y_train_std, likelihood, mll):
     # Train mode for model + likelihood
     model.train(); likelihood.train()
     prev_loss = None
-    for i in range(10000):
+    for i in range(250):
         optimizer.zero_grad()
         output = model(X_train)
         loss = -mll(output, y_train_std)
@@ -32,11 +32,11 @@ def optimise_model (model, X_train, y_train_std, likelihood, mll):
         loss.backward()
         optimizer.step()
         # Early stopping based on tolerance
-        if prev_loss is not None and abs(prev_loss - loss_value) < 0.001:
-            # print(f"Converged at iteration {i} with change {abs(prev_loss - loss_value):.6e}")
-            break
+        if prev_loss is not None and abs(prev_loss - loss_value) < 0.00001:
+           #print(f"Converged at iteration {i} with change {abs(prev_loss - loss_value):.6e}")
+           break
+
 
-        
         prev_loss = loss_value
 
 def converge_check(imse, patience=100, slope_tol=1e-3):
@@ -56,7 +56,7 @@ def converge_check(imse, patience=100, slope_tol=1e-3):
 
     recent = np.array(imse[-patience:])
 
-   
+
 
     # Compute average slope (simple linear regression)
     x = np.arange(len(recent))
@@ -70,7 +70,7 @@ def converge_check(imse, patience=100, slope_tol=1e-3):
 
 
 def query_model(model, probe_pts, y_std, y_mean,likelihood=None):
-    
+
     """
     Queries a Gaussian Process model at a set of probe points.
 
@@ -91,7 +91,7 @@ def query_model(model, probe_pts, y_std, y_mean,likelihood=None):
     with torch.no_grad():
         if likelihood is not None:
             test_noise = torch.full((probe_pts.shape[0],), 0.5 / (y_std**2), dtype=torch.double)
-            preds = likelihood(model(probe_pts))
+            preds = likelihood(model(probe_pts), noise=test_noise)
         else:
             preds = model(probe_pts)
         mean_pred = preds.mean * y_std + y_mean     # de-standardize back to eV
@@ -161,15 +161,13 @@ def estimate_imse(model, likelihood, probe_pts, y_std, theta_range, phi_range):
         phi_min, phi_max = 0, 2 * np.pi
     # Fraction of total surface area of sphere (to scale IMSE expression)
     area_fraction = (phi_max - phi_min) * (np.cos(theta_min) - np.cos(theta_max)) / (4 * np.pi)
-    model = model.double()
-    probe_pts = probe_pts.double()
+
     # Don't compute gradients for resources, use fater vairance prediction at minimal accuracy loss
-    with torch.no_grad():
+    with torch.no_grad(), gpytorch.settings.cholesky_jitter(1e-8):
         # Extract model predictions at probe points
         preds = model(probe_pts)
         # Preds is GPyTorch MultivariateNormal object with .mean and .variance
         # Multiply by train_y_std^2 to get variance in original units
         var = torch.clamp(preds.variance, min=0.0) * (y_std**2)
     # Integrating over sphere requires 4 pi multiplier so variance spread over the whole sphere gives higher value.
-    return area_fraction * ((4*pi )/ probe_pts.shape[0]) * var.sum().item() # Sum of vairance at all points, multiplied by weight factor (float)
-
+    return area_fraction * ((4*pi )/ probe_pts.shape[0]) * var.sum().item() # Sum of vairance at all points, multiplied by weight factor (float)
\ No newline at end of file
