@@ -48,19 +48,19 @@ def demap(cfg, theta_range: Optional[Tuple[float, float]] = None,
     """
 
 
-    startup_text = f'''
+    startup_text = rf'''
 ---------------------------------------------
-  ___  ___                
- |   \| __|_ __  __ _ _ __ 
- | |) | _|| '  \/ _` | '_ \ 
- |___/|___|_|_|_\__,_| .__/ 
+  ___  ___
+ |   \| __|_ __  __ _ _ __
+ | |) | _|| '  \/ _` | '_ \
+ |___/|___|_|_|_\__,_| .__/
                      |_|
 
-VERSION: {__version__} 
+VERSION: {__version__}
 AUTHOR: Ashley Dickson
 CORRESPONDANCE: a.dickson2@lancaster.ac.uk
 ---------------------------------------------
-    ''' 
+    '''
     print(startup_text)
     # Validate theta_range
     if theta_range is not None:
@@ -77,10 +77,10 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
                 f"Invalid phi_range {phi_range}. "
                 f"It must satisfy 0 <= phi_min < phi_max <= 2pi."
             )
-    # Initialise seeds to maintain stability on restart   
+    # Initialise seeds to maintain stability on restart
     np.random.seed(cfg.random_seed)
     torch.manual_seed(cfg.random_seed)
-    # Load checkpoint file on restart 
+    # Load checkpoint file on restart
     checkpoint = load_checkpoint() if restart else None
     # Initialise list of IMSE for each iteration
     imse_list = []
@@ -90,16 +90,16 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
         y_train = checkpoint['y_train']
         noise_train = checkpoint['noise_train']
         start_idx = X_train.shape[0]
-        init_pts = torch.tensor(fibonacci_sphere(n=cfg.init_n, theta_range=theta_range, phi_range=phi_range))
+        init_pts = torch.tensor(fibonacci_sphere(n=cfg.init_n, theta_range=theta_range, phi_range=phi_range), dtype=torch.double)
         print(f"Resuming initial sampling at point {start_idx}/{len(init_pts)}")
     elif not checkpoint:
-        # Run from scratch w/o restart 
+        # Run from scratch w/o restart
         print('Starting initial point sampling...')
-        init_pts = torch.tensor(fibonacci_sphere(n=cfg.init_n, theta_range=theta_range, phi_range=phi_range), dtype=torch.float32)
+        init_pts = torch.tensor(fibonacci_sphere(n=cfg.init_n, theta_range=theta_range, phi_range=phi_range), dtype=torch.double)
         print('Total number of initial points:', len(init_pts))
-        X_train = torch.empty((0, len(init_pts[0])), dtype=torch.float32)
-        y_train = torch.empty((0,), dtype=torch.float32)
-        noise_train = torch.empty((0,), dtype=torch.float32)
+        X_train = torch.empty((0, len(init_pts[0])), dtype=torch.double)
+        y_train = torch.empty((0,), dtype=torch.double)
+        noise_train = torch.empty((0,), dtype=torch.double)
         start_idx = 0
     else:
         # Loaded full checkpoint (past init)
@@ -109,29 +109,29 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
         noise_train = checkpoint['noise_train']
         start_idx = None
 
-    # Initial sampling 
+    # Initial sampling
     if start_idx is not None:
         for i in range(start_idx, len(init_pts)):
             u = init_pts[i]
             val, noise = evaluate_tde(cfg=cfg, u=u)
             print(f"TDE of initial point {i+1}/{len(init_pts)}: {val:.2f} eV")
 
-            X_train = torch.cat([X_train, u.unsqueeze(0).clone().detach()])
-            y_train = torch.cat([y_train, torch.tensor([val])])
-            noise_train = torch.cat([noise_train, torch.tensor([noise])])
+            X_train = torch.cat([X_train, u.unsqueeze(0).clone().detach()]).double()
+            y_train = torch.cat([y_train, torch.tensor([val])]).double()
+            noise_train = torch.cat([noise_train, torch.tensor([noise])]).double()
 
             save_checkpoint(X_train, y_train, noise_train, i, imse_list, stage="init")
 
         print('Initial points sampled...')
 
-    # Build GP model 
+    # Build GP model
     y_mean = y_train.mean()
     y_std = y_train.std()
     # Standardise to unit variance and zero mean
-    y_train_std = (y_train - y_mean) / y_std
+    y_train_std = ((y_train - y_mean) / y_std).double()
 
     # standardise Gaussian noise
-    noise_train_std = noise_train / (y_std ** 2)
+    noise_train_std = (noise_train / (y_std ** 2)).double()
 
     # Likelihood (noise) model
     likelihood = gpytorch.likelihoods.FixedNoiseGaussianLikelihood(
@@ -140,25 +140,26 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
     model = ExactGPModel(X_train, y_train_std, likelihood)
     mll = gpytorch.mlls.ExactMarginalLogLikelihood(likelihood, model)
 
-    # Optimise model hyperparams given initial data 
+    # Optimise model hyperparams given initial data
     optimise_model(model, X_train, y_train_std, likelihood, mll)
 
     # Generate probe points on sphere (randomly distributed)
-    probe = torch.tensor(random_sphere_points(n=cfg.probe_n, theta_range=theta_range, phi_range=phi_range), dtype=torch.float32)
-    
-    # Iterative loop 
+    probe = torch.tensor(fibonacci_sphere(n=cfg.probe_n, theta_range=theta_range, phi_range=phi_range), dtype=torch.double)
+    #probe = torch.tensor(random_sphere_points(n=cfg.probe_n, theta_range=theta_range, phi_range=phi_range), dtype=torch.float32)
+
+    # Iterative loop
     start_it = checkpoint['iteration'] + 1 if checkpoint and checkpoint['stage'] == "iter" else 1
-    
+
     for it in range(start_it, cfg.max_iters + 1):
-        
-        imse = estimate_imse(model, likelihood, probe, y_std, theta_range, phi_range)
+
+        imse = estimate_imse(model=model, likelihood=likelihood, probe_pts= probe, y_std = y_std, theta_range=theta_range, phi_range=phi_range)
         imse_list.append(imse)
         if converge_check(imse_list):
             print('IMSE converged, exiting...')
             break
 
         save_checkpoint(X_train, y_train, noise_train, it, imse, stage="iter")
-        
+
         # Grab predicted variance at all probe points
         _, var_pred = query_model(model=model, likelihood=likelihood, probe_pts=probe, y_std=y_std, y_mean=y_mean)
         idx = torch.argmax(var_pred).item()
@@ -168,14 +169,14 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
 
         # Predict TDE of next point
         pred_mean, pred_var = query_model(model=model, likelihood=likelihood, probe_pts=new_pts, y_std=y_std, y_mean=y_mean)
-     
-        
+
+
         # Efficient TDE evaluation by inclusion of guess start energy two standard deviations below predicted TDE, if lower than 1 eV
         # otherwise start from 1 eV
         guess_start_energy = max(int(round(pred_mean[0].item() - (pred_var[0].sqrt().item() * 2))), 1)
         # New TDE and new Noise
         new_y, new_n = [], []
-        
+
         val, noise = evaluate_tde(cfg=cfg,u=new_pts[0], start_energy=guess_start_energy)
         if it == start_it:
             print(f"{'Iter':>5} | {'Evaluated TDE (eV)':>20} | {'Predicted TDE (eV)':>22} | {'IMSE':>8}")
@@ -194,7 +195,7 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
         X_train = torch.cat([X_train, new_pts])
         y_train = torch.cat([y_train, torch.tensor(new_y)])
         noise_train = torch.cat([noise_train, torch.tensor(new_n)])
-        # Renormalise data 
+        # Renormalise data
         y_mean = y_train.mean()
         y_std = y_train.std()
         y_train_std = (y_train - y_mean) / y_std
@@ -207,7 +208,7 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
         optimise_model(model, X_train, y_train_std, likelihood, mll)
         # Create arrays for evaluations at probe points
         # mean_pred, var_pred = query_model(model=model, likelihood=likelihood, probe_pts=probe, y_std=y_std, y_mean=y_mean)
-        
+
         # np.savetxt('probe_points.txt', probe.numpy())
         # np.savetxt('tde_points.txt', mean_pred.numpy())
         # np.savetxt('var_points.txt', var_pred.numpy())
@@ -230,13 +231,13 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
         Plot_Tools(X_train_np, train_y_np, theta_range=theta_range, phi_range=phi_range).plot(plot_type="mean", fname='TDEMAP.png')
         #Plot variance
         Plot_Tools(X_train_np, var_pred.numpy(), theta_range=theta_range, phi_range=phi_range).plot(plot_type="var", fname='VARMAP.png')
-    
 
- 
+
+
 
 # if __name__ == "__main__":
-#     generate_lammps_input(masses = [(1, 55.845)], pair_styles = ['pair_style hybrid/overlay eam/fs tabgap'], 
-#                            pair_coeffs = ['pair_coeff * * eam/fs ../Fe-2021-04-06.eam.fs Fe', 
+#     generate_lammps_input(masses = [(1, 55.845)], pair_styles = ['pair_style hybrid/overlay eam/fs tabgap'],
+#                            pair_coeffs = ['pair_coeff * * eam/fs ../Fe-2021-04-06.eam.fs Fe',
 #                                           'pair_coeff * * tabgap ../Fe-2021-04-06.tabgap Fe no yes'],
 #                              units = 'metal', atom_style = 'atomic', read_data = 'Fe.data', run_steps = 2000, PKA_id=4367)
 
@@ -244,4 +245,3 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
 #                                init_n=200, max_iters=1400)
 
 #     demap(theta_range=(0, np.pi/4), phi_range=(0, np.pi/4), restart=False, cfg=cfg, plot=False)
-
